﻿using System;
using System.Drawing;
using System.Web.Script.Serialization;

using MindFusion.Diagramming;
using MindFusion.Diagramming.WebForms;

using Image = System.Drawing.Image;
using Bitmap = System.Drawing.Bitmap;
using Graphics = System.Drawing.Graphics;


public partial class Default : System.Web.UI.Page
{
    protected void Page_Init(object sender, EventArgs e)
    {
        // register custom item types, their serialization identifiers and JavaScript class names

		// this class demonstrates custom drawing in Canvas mode, see Scripts/CustomNode.js
        diagramView.RegisterItemType(typeof(CustomNode), "CustomNode", "CustomNode", 100);

		// these classes demonstrate custom drawing in ImageMap mode, see IconNode.cs and IconLink.cs
        diagramView.RegisterItemType(typeof(IconNode), "IconNode", "IconNode", 100);
        diagramView.RegisterItemType(typeof(IconLink), "IconLink", "IconLink", 100);

		// register converters for serializing .NET items into JSON objects
        diagramView.RegisterConverters(new JavaScriptConverter[]
		{ 
            new CustomNodeConverter(diagramView),
            new IconNodeConverter(diagramView),
            new IconLinkConverter(diagramView)
		});
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        diagramView.ClientSideMode = radioButtonList.SelectedIndex == 0 ?
			ClientSideMode.Canvas : ClientSideMode.ImageMap;

        // let users draw CustomNode objects in Canvas mode
        if (diagramView.ClientSideMode == ClientSideMode.Canvas)
        {
            diagramView.CustomNodeType = typeof(CustomNode);
            diagramView.NodeClickedScript = "onNodeClicked";
        }

        // let users draw IconNode/IconLink objects in ImageMap mode
        else if (diagramView.ClientSideMode == ClientSideMode.ImageMap)
        {
            diagramView.CustomNodeType = typeof(IconNode);
            diagramView.CustomLinkType = typeof(IconLink);
        }
    }

    protected void OnNodeClicked(object sender, NodeEventArgs e)
    {
        IconNode iconNode = e.Node as IconNode;
        if (iconNode != null)
        {
            Image icon =  new Bitmap(48, 48);

            Graphics graphics = Graphics.FromImage(icon);
            Font font = new Font("Arial", 48, FontStyle.Bold, GraphicsUnit.Pixel);

            graphics.FillRectangle(Brushes.White, 0, 0, 48, 48);
            graphics.TextRenderingHint = System.Drawing.Text.TextRenderingHint.AntiAlias;
            graphics.DrawString("!", font, Brushes.Firebrick, 0, 0);

            font.Dispose();
            graphics.Dispose();

            iconNode.Icon = icon;
            iconNode.Label = "clicked";
        }
    }

    protected void OnLinkClicked(object sender, LinkEventArgs e)
    {
        IconLink iconLink = e.Link as IconLink;
        if (iconLink != null)
            iconLink.MidPointShape = IconLink.PointShape.Rectangle;
    }

    protected void OnRadioSelectedIndexChanged(object sender, EventArgs e)
    {
        diagramView.Diagram.ClearAll();
    }

    protected void OnSubmitClick(object sender, EventArgs e)
    {
    }
}